@@ -28,7 +28,7 @@ function save_me() {
 
 function rename_save(prefix) {
     var current_name = Jupyter.notebook.notebook_name;
-    let base_name = Jupyter.notebook.metadata.savedownload.base_name || "Exam";
+    let base_name = Jupyter.notebook.metadata.savedownload?.base_name || "Exam";
     let new_name = prefix + "_" + base_name;
     
     if (current_name.substring(0, current_name.length - 6) != new_name) {
